% Each section in the code corresponds to individual plots, can be run
% independently

%% plot mu_{t2} vs mu_{t1}

% parameters
N=10;
nt1=4; nt2=7;
munt=5; t=1; del=0.5;
mut1=0.01:0.01:1;
mut2=0.01:0.01:1;
s1=size(mut1,2);
s2=size(mut2,2);

ediff=zeros(s1,s2);
[ca,cc]=creationoperators(2*N);
[hmut1,hmut2,hmunt,ht,hd,~]=kitaevchain_3segments_hamiltonian(N,nt1,nt2,cc,ca);
 h=munt*hmunt+t*ht+del*hd;


for i=1:s1
for j=1:s2
hf=h+mut1(1,i)*hmut1+mut2(1,j)*hmut2;
ed=eig(hf);
ediff(i,j)=ed(4)-ed(1);
end
end

% plot figure
x=mut1;
y=mut2;
z=ediff;
figure
imagesc(x,y,z)
set(gca,'YDir','normal')
CT=cbrewer('seq','OrRd',4096);
colormap(CT)
colorbar
c = colorbar;
c.LineWidth = 0.8;
c.FontSize = 20;
set(gca,'FontSize',32)
xlabel('\mu_{t1}','FontWeight','bold');
ylabel('\mu_{t2}','FontWeight','bold');



%% plot mu_{nt} vs mu_{t1}

% parameters
N=10;
nt1=4; nt2=7;
mut2=0.1; t=1; del=0.5;
mut1=0.01:0.01:1;
munt=3:0.05:10;
s1=size(mut1,2);
s2=size(munt,2);

ediff=zeros(s1,s2);
[ca,cc]=creationoperators(2*N);
[hmut1,hmut2,hmunt,ht,hd,~]=kitaevchain_3segments_hamiltonian(N,nt1,nt2,cc,ca);
 h=mut2*hmut2+t*ht+del*hd;


for i=1:s1
for j=1:s2
hf=h+mut1(1,i)*hmut1+munt(1,j)*hmunt;
ed=eig(hf);
ediff(i,j)=ed(4)-ed(1);
end
end

plot figure
x=mut1;
y=munt;
z=ediff;
figure
imagesc(x,y,z)
set(gca,'YDir','normal')
CT=cbrewer('seq','OrRd',4096);
colormap(CT)
colorbar
c = colorbar;
w = c.LineWidth;
c.LineWidth = 0.8;
c.FontSize = 20;
set(gca,'FontSize',32)
xlabel('\mu_{t1}','FontWeight','bold');
ylabel('\mu_{nt}','FontWeight','bold');

%% plot t vs mu_{t1}

% parameters
N=10;
nt1=4; nt2=7;
mut2=0.1; munt=5; del=0.5;
mut1=0.01:0.01:1;
t=0.01:0.01:1;
s1=size(mut1,2);
s2=size(t,2);

ediff=zeros(s1,s2);
[ca,cc]=creationoperators(2*N);
[hmut1,hmut2,hmunt,ht,hd,~]=kitaevchain_3segments_hamiltonian(N,nt1,nt2,cc,ca);
 h=mut2*hmut2+munt*hmunt+del*hd;


for i=1:s1
for j=1:s2
hf=h+mut1(1,i)*hmut1+t(1,j)*ht;
ed=eig(hf);
ediff(i,j)=ed(4)-ed(1);
end
end

% plot figure
x=mut1;
y=t;
z=ediff;
figure
imagesc(x,y,z)
set(gca,'YDir','normal')
CT=cbrewer('seq','OrRd',4096);
colormap(CT)
colorbar
c = colorbar;
c.LineWidth = 0.8;
c.FontSize = 20;
set(gca,'FontSize',32)
xlabel('\mu_{t1}','FontWeight','bold');
ylabel('t','FontWeight','bold');

%% plot del vs mu_{t1}

% parameters
N=10;
nt1=4; nt2=7;
mut2=0.1; munt=5; t=1;
mut1=0.01:0.01:1;
del=0.01:0.01:1;
s1=size(mut1,2);
s2=size(del,2);

ediff=zeros(s1,s2);
[ca,cc]=creationoperators(2*N);
[hmut1,hmut2,hmunt,ht,hd,~]=kitaevchain_3segments_hamiltonian(N,nt1,nt2,cc,ca);
 h=mut2*hmut2+munt*hmunt+t*ht;


for i=1:s1
for j=1:s2
hf=h+mut1(1,i)*hmut1+del(1,j)*hd;
ed=eig(hf);
ediff(i,j)=ed(4)-ed(1);
end
end

% plot figure
x=mut1;
y=del;
z=ediff;
figure
imagesc(x,y,z)
set(gca,'YDir','normal')
CT=cbrewer('seq','OrRd',4096);
colormap(CT)
colorbar
c = colorbar;
c.LineWidth = 0.8;
c.FontSize = 20;
set(gca,'FontSize',32)
xlabel('\mu_{t1}','FontWeight','bold');
ylabel('\Delta','FontWeight','bold');

%% plot mu_{nt} vs mu_{t2} 

% parameters
N=10;
nt1=4; nt2=7;
mut1=0.1; t=1; del=0.5;
mut2=0.01:0.01:1;
munt=3:0.05:10;
s1=size(mut2,2);
s2=size(munt,2);

ediff=zeros(s1,s2);
[ca,cc]=creationoperators(2*N);
[hmut1,hmut2,hmunt,ht,hd,~]=kitaevchain_3segments_hamiltonian(N,nt1,nt2,cc,ca);
h=mut1*hmut1+t*ht+del*hd;


for i=1:s1
for j=1:s2
hf=h+mut2(1,i)*hmut2+munt(1,j)*hmunt;
ed=eig(hf);
ediff(i,j)=ed(4)-ed(1);
end
end

% plot figure
x=mut2;
y=munt;
z=ediff;
figure
imagesc(x,y,z)
set(gca,'YDir','normal')
CT=cbrewer('seq','OrRd',4096);
colormap(CT)
colorbar
c = colorbar;
c.LineWidth = 0.8;
c.FontSize = 20;
set(gca,'FontSize',32)
xlabel('\mu_{t2}','FontWeight','bold');
ylabel('\mu_{nt}','FontWeight','bold');


%% plot t vs mu_{t2}

% parameters
N=10;
nt1=4; nt2=7;
mut1=0.1; munt=5; del=0.5;
mut2=0.01:0.01:1;
t=0.01:0.01:1;
s1=size(mut2,2);
s2=size(t,2);

ediff=zeros(s1,s2);
[ca,cc]=creationoperators(2*N);
[hmut1,hmut2,hmunt,ht,hd,~]=kitaevchain_3segments_hamiltonian(N,nt1,nt2,cc,ca);
 h=mut1*hmut1+munt*hmunt+del*hd;


for i=1:s1
for j=1:s2
hf=h+mut2(1,i)*hmut2+t(1,j)*ht;
ed=eig(hf);
ediff(i,j)=ed(4)-ed(1);
end
end

% plot figure
x=mut2;
y=t;
z=ediff;
figure
imagesc(x,y,z)
set(gca,'YDir','normal')
CT=cbrewer('seq','OrRd',4096);
colormap(CT)
colorbar
c = colorbar;
c.LineWidth = 0.8;
c.FontSize = 20;
set(gca,'FontSize',32)
xlabel('\mu_{t2}','FontWeight','bold');
ylabel('t','FontWeight','bold');

%% plot del vs mu_{t2}

% parameters
N=10;
nt1=4; nt2=7;
mut1=0.1; munt=5; t=1;
mut2=0.01:0.01:1;
del=0.01:0.01:1;
s1=size(mut2,2);
s2=size(del,2);

ediff=zeros(s1,s2);
[ca,cc]=creationoperators(2*N);
[hmut1,hmut2,hmunt,ht,hd,~]=kitaevchain_3segments_hamiltonian(N,nt1,nt2,cc,ca);
 h=mut1*hmut1+munt*hmunt+t*ht;


for i=1:s1
for j=1:s2
hf=h+mut2(1,i)*hmut2+del(1,j)*hd;
ed=eig(hf);
ediff(i,j)=ed(4)-ed(1);
end
end

% plot figure
x=mut2;
y=del;
z=ediff;
figure
imagesc(x,y,z)
set(gca,'YDir','normal')
CT=cbrewer('seq','OrRd',4096);
colormap(CT)
colorbar
c = colorbar;
c.LineWidth = 0.8;
c.FontSize = 20;
set(gca,'FontSize',32)
xlabel('\mu_{t2}','FontWeight','bold');
ylabel('\Delta','FontWeight','bold');


%% plot t vs mu_{nt} 

% parameters
N=10;
nt1=4; nt2=7;
mut1=0.1; mut2=0.8; del=0.5;
munt=3:0.05:10;
t=0.01:0.01:1;
s1=size(munt,2);
s2=size(t,2);

ediff=zeros(s1,s2);
[ca,cc]=creationoperators(2*N);
[hmut1,hmut2,hmunt,ht,hd,~]=kitaevchain_3segments_hamiltonian(N,nt1,nt2,cc,ca);
h=mut1*hmut1+mut2*hmut2+del*hd;


for i=1:s1
for j=1:s2
hf=h+munt(1,i)*hmunt+t(1,j)*ht;
ed=eig(hf);
ediff(i,j)=ed(4)-ed(1);
end
end

% plot figure
x=munt;
y=t;
z=ediff;
figure
imagesc(x,y,z)
set(gca,'YDir','normal')
CT=cbrewer('seq','OrRd',4096);
colormap(CT)
colorbar
c = colorbar;
c.LineWidth = 0.8;
c.FontSize = 20;
set(gca,'FontSize',32)
xlabel('\mu_{nt}','FontWeight','bold');
ylabel('t','FontWeight','bold');

%% plot Delta vs mu_{nt} 

% parameters
N=10;
nt1=4; nt2=7;
mut2=0.1; mut1=0.1; t=1;
munt=3:0.05:10;
del=0.01:0.01:1;
s1=size(munt,2);
s2=size(del,2);

ediff=zeros(s1,s2);
[ca,cc]=creationoperators(2*N);
[hmut1,hmut2,hmunt,ht,hd,~]=kitaevchain_3segments_hamiltonian(N,nt1,nt2,cc,ca);
h=mut1*hmut1+mut2*hmut2+t*ht;


for i=1:s1
for j=1:s2
hf=h+munt(1,i)*hmunt+del(1,j)*hd;
ed=eig(hf);
ediff(i,j)=ed(4)-ed(1);
end
end

% plot figure
x=munt;
y=del;
z=ediff;
figure
imagesc(x,y,z)
set(gca,'YDir','normal')
CT=cbrewer('seq','OrRd',4096);
colormap(CT)
colorbar
c = colorbar;
c.LineWidth = 0.8;
c.FontSize = 20;
set(gca,'FontSize',32)
xlabel('\mu_{nt}','FontWeight','bold');
ylabel('\Delta','FontWeight','bold');

%% plot del vs t

% parameters
N=10;
nt1=4; nt2=7;
mut2=0.1; munt=5; mut1=0.1;
t=0.01:0.05:1;
del=0.01:0.05:1;
s1=size(t,2);
s2=size(del,2);

ediff=zeros(s1,s2);
[ca,cc]=creationoperators(2*N);
[hmut1,hmut2,hmunt,ht,hd,~]=kitaevchain_3segments_hamiltonian(N,nt1,nt2,cc,ca);
 h=mut1*hmut1+mut2*hmut2+munt*hmunt;


for i=1:s1
for j=1:s2
hf=h+t(1,i)*ht+del(1,j)*hd;
ed=eig(hf);
ediff(i,j)=ed(4)-ed(1);
end
end

% plot figure
x=t;
y=del;
z=ediff;
figure
imagesc(x,y,z)
set(gca,'YDir','normal')
CT=cbrewer('seq','OrRd',4096);
colormap(CT)
colorbar
c = colorbar;
c.LineWidth = 0.8;
c.FontSize = 20;
set(gca,'FontSize',32)
xlabel('t','FontWeight','bold');
ylabel('\Delta','FontWeight','bold');









